Imports System.IO

Partial Class Create_read_delete_text_file
    Inherits System.Web.UI.Page

    Protected Sub CreateTextFile_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles CreateTextFile.Click

        ' This code will create a txt file with the content in the textbox "txtTextFileText" when the user
        ' has clicked the button. Note that you need to have the folder "files" to be able to create the
        ' file.

        Try
            ' The Using block is used to call dispose (close) automatically even if there are an exception.
            Using Writer As StreamWriter = File.CreateText(Server.MapPath("files/mytestfile.txt"))
                Writer.WriteLine(txtTextFileText.Text)
                lblMessage.Text = "Your file has been created!"
            End Using

        Catch ex As Exception
            lblMessage.Text = "The file could not be created, the errormessage is: " & ex.ToString()
        Finally
        End Try
    End Sub

    Protected Sub btnAppendText_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnAppendText.Click

        ' This code will append text to a txt file with the content in the textbox "txtAppendText" when the user
        ' has clicked the button. If the file doesnt exist we get a FileNotFound exception and
        ' it could therefore be good to check if the file exists before we try to add text to the file.

        Try
            ' The Using block is used to call dispose (close) automatically even if there are an exception.
            Using Appender As StreamWriter = File.AppendText(Server.MapPath("files/mytestfile.txt"))
                Appender.WriteLine(txtAppendText.Text)
                lblMessage2.Text = "Your text has been added!"
            End Using

        Catch ex As Exception
            lblMessage2.Text = "The text could not be added, the errormessage is: " & ex.ToString()
        Finally
        End Try

        'AN ALTERNATIVE APPROACH TO CHECK IF THE FILE EXISTS BEFORE WE TRY TO APPEND TEXT TO IT
        'Try
        '    Dim FileToAppendTo As FileInfo = New FileInfo(Server.MapPath("files/mytestfile.txt"))
        '    If FileToAppendTo.Exists Then
        '        Using Appender As StreamWriter = File.AppendText(FileToAppendTo.ToString())
        '            Appender.WriteLine(txtAppendText.Text)
        '            lblMessage2.Text = "Your text has been added!"
        '        End Using
        '    End If
        'Catch ex As Exception
        '    lblMessage2.Text = "Could not read from the file, the errormessage is: " & ex.ToString()
        'Finally
        'End Try

    End Sub

    Protected Sub btnReadFile_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnReadFile.Click

        ' This code will read the text from a txt file when the user has clicked the button and output
        ' the content to a label "lblReadText". If the file doesnt exist we get a FileNotFound exception and
        ' it could therefore be good to check if the file exists before we try to read from the file.

        Try
            ' The Using block is used to call dispose (close) automatically even if there are an exception.
            Using Reader As StreamReader = File.OpenText(Server.MapPath("files/mytestfile.txt"))
                Dim Content As String = Reader.ReadToEnd()
                lblReadText.Text = Content.Replace(vbCrLf, "<br>")
            End Using
        Catch ex As Exception
            lblReadText.Text = "Could not read from the file, the errormessage is: " & ex.ToString()
        Finally
        End Try

        ' AN ALTERNATIVE APPROACH TO CHECK IF THE FILE EXISTS BEFORE WE TRY TO READ FROM IT
        Try
            Dim FileToRead As FileInfo = New FileInfo(Server.MapPath("files/mytestfile.txt"))
            If FileToRead.Exists Then
                Using Reader As StreamReader = File.OpenText(FileToRead.ToString())
                    Dim Content As String = Reader.ReadToEnd()
                    lblReadText.Text = Content.Replace(vbCrLf, "<br>")
                End Using
            End If
        Catch ex As Exception
            lblReadText.Text = "Could not read from the file, the errormessage is: " & ex.ToString()
        Finally
        End Try
    End Sub

    Protected Sub btnDeleteFile_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnDeleteFile.Click

        ' This code will delete a txt file when the user has clicked the button. If the file doesnt exist we want to get 
        ' a FileNotFound exception and therefore we have code in the "Else" statement.

        Try
            Dim FileToDelete As FileInfo = New FileInfo(Server.MapPath("files/mytestfile.txt"))
            If FileToDelete.Exists Then
                FileToDelete.Delete()
                lblDeleteMessage.Text = "You have successfully deleted the file"
            Else
                Throw New FileNotFoundException()
            End If
        Catch ex As FileNotFoundException
            lblDeleteMessage.Text = "Could not delete the file, the errormessage is: " & ex.ToString()
        Finally
        End Try
    End Sub

    Protected Sub btnNewTextFileToUser_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnNewTextFileToUser.Click

        ' This code will create a txt file with the content in the textbox "txtTextFileText" when the user
        ' has clicked the button. The text file is not saved to the webserver but the user is offered
        ' to download the file to his local computer.

        Try
            ' The Using block is used to call dispose (close) automatically even if there are an exception.
            Using Writer As StreamWriter = New StreamWriter(Response.OutputStream)
                Writer.WriteLine(txtTextForUserTextFile.Text)
            End Using

            ' Give the user a "Save As Dialog" to download the text file
            Response.ContentType = "Application/txt"
            Response.AppendHeader("Content-Disposition", "attachment; filename=MyOwnTextFile.txt")
            Response.Flush()
            Response.Close()

        Catch ex As Exception
            ErrorMessage.Text = "The file could not be created, the errormessage is: " & ex.ToString()
        Finally
        End Try
    End Sub

    Protected Sub btnDownload_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles btnDownload.Click

        ' This code will will give the user a "Save As Dialog" to download a text file from our
        ' webserver when he has clicked the button. If the file doesnt exist we want to get 
        ' a FileNotFound exception and therefore we have code in the "Else" statement. The
        ' term "octet-stream" makes it possible to download any type of file.

        Try
            Dim FilePath As String = "files/mytestfile.txt"
            Dim LookForFile As FileInfo = New FileInfo(Server.MapPath(FilePath))

            If LookForFile.Exists Then

                ' Give the user a Save As Dialog to download the text file
                Response.Clear()
                Response.ContentType = ("application/octet-stream")
                Response.AppendHeader("Content-Disposition", "attachment; filename=MyOwnFile.txt")
                Response.WriteFile(Server.MapPath(FilePath))
                Response.Flush()
                Response.Close()
            Else
                Throw New FileNotFoundException()
            End If
        Catch ex As FileNotFoundException
            ErrorMessage2.Text = "The file could not be downloaded, the errormessage is: " & ex.ToString()
        Finally
        End Try
    End Sub
End Class
