using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

public partial class Create_read_delete_files : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // No code in the Page_Load event yet.
    }

    protected void CreateTextFile_Click(object sender, EventArgs e)
    {
        // This code will create a txt file with the content in the textbox "txtTextFileText" when the user
        // has clicked the button. Note that you need to have the folder "files" to be able to create the
        // file.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            // Create a StreamWriter. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (StreamWriter Writer = File.CreateText(Server.MapPath("files/mytestfile.txt")))
            {
                Writer.WriteLine(txtTextFileText.Text);
                lblMessage.Text = "Your file has been created!";
            }

        }
        catch (Exception ex)
        {
            lblMessage.Text = "The file could not be created, the errormessage is: " + ex.ToString();
        }
        finally
        {
            // No code to dispose of resources because we have a using block.
        }
    }
    protected void btnAppendText_Click(object sender, EventArgs e)
    {
        
        // This code will append text to a txt file with the content in the textbox "txtAppendText" when the user
        // has clicked the button. If the file doesnt exist we get a FileNotFound exception and
        // it could therefore be good to check if the file exists before we try to add text to the file.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            // Create a StreamWriter. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (StreamWriter Appender = File.AppendText(Server.MapPath("files/mytestfile.txt")))
            {
                Appender.WriteLine(txtAppendText.Text);
                lblMessage2.Text = "Your text has been added!";
            }

        }
        catch (Exception ex)
        {
            lblMessage2.Text = "The text could not be added, the errormessage is: " + ex.ToString();
        }
        finally
        {
            // No code to dispose of resources because we have a using block.
        }

        //AN ALTERNATIVE APPROACH TO CHECK IF THE FILE EXISTS BEFORE WE TRY TO APPEND TEXT TO IT
        //try
        //{
        //    FileInfo FileToAppendTo = new FileInfo(Server.MapPath("files/mytestfile.txt"));

        //    if (FileToAppendTo.Exists)
        //    {
        //        using (StreamWriter Appender = File.AppendText(FileToAppendTo.ToString()))
        //        {
        //            Appender.WriteLine(txtAppendText.Text);
        //            lblMessage2.Text = "Your text has been added!";
        //        }
        //    }
        //}
        //catch (Exception ex)
        //{
        //    lblMessage2.Text = "Could not read from the file, the errormessage is: " + ex.ToString();
        //}
        //finally
        //{
        //    // No code to dispose of resources because we have a using block.
        //}

    }

    protected void btnReadFile_Click(object sender, EventArgs e)
    {
        // This code will read the text from a txt file when the user has clicked the button and output
        // the content to a label "lblReadText". If the file doesnt exist we get a FileNotFound exception and
        // it could therefore be good to check if the file exists before we try to read from the file.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            // Create a StreamReader. The using block is used to call dispose (close) automatically even 
            // if there are an exception.
            using (StreamReader Reader = File.OpenText(Server.MapPath("files/mytestfile.txt")))
            {
                string Content = Reader.ReadToEnd();
                lblReadText.Text = Content.Replace("\r\n", "<br>");
            }
        }
        catch (Exception ex)
        {
            lblReadText.Text = "Could not read from the file, the errormessage is: " + ex.ToString();
        }
        finally
        {
        }

        // AN ALTERNATIVE APPROACH TO CHECK IF THE FILE EXISTS BEFORE WE TRY TO READ FROM IT
        //try
        //{
        //    FileInfo FileToRead = new FileInfo(Server.MapPath("files/mytestfile.txt"));
        //    if (FileToRead.Exists)
        //    {
        //        using (StreamReader Reader = File.OpenText(FileToRead.ToString()))
        //        {
        //            string Content = Reader.ReadToEnd();
        //            lblReadText.Text = Content.Replace("\r\n", "<br>");
        //        }
        //    }
        //}
        //catch (Exception ex)
        //{
        //    lblReadText.Text = "Could not read from the file, the errormessage is: " + ex.ToString();
        //}
        //finally
        //{
        //}
    }

    protected void btnDeleteFile_Click(object sender, EventArgs e)
    {
        // This code will delete a txt file when the user has clicked the button. If the file doesnt exist we want to get 
        // a FileNotFound exception and therefore we have code in the "else" statement.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            FileInfo FileToDelete = new FileInfo(Server.MapPath("files/mytestfile.txt"));
            if (FileToDelete.Exists)
            {
                FileToDelete.Delete();
                lblDeleteMessage.Text = "You have successfully deleted the file";
            }
            else
            {
                throw new FileNotFoundException();
            }
        }
        catch (FileNotFoundException ex)
        {
            lblDeleteMessage.Text = "Could not delete the file, the errormessage is: " + ex.ToString();
        }
        finally
        {
        }
    }
    protected void btnNewTextFileToUser_Click(object sender, EventArgs e)
    {
        // This code will create a txt file with the content in the textbox "txtTextFileText" when the user
        // has clicked the button. The text file is not saved to the webserver but the user is offered
        // to download the file to his local computer.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            // Create a StreamWriter. The using block is used to call dispose (close) automatically even 
            // if there are an exception.
            using (StreamWriter Writer = new StreamWriter(Response.OutputStream))
            {
                Writer.WriteLine(txtTextForUserTextFile.Text);
            }

            // Give the user a "Save As Dialog" to download the text file
            Response.ContentType = "Application/txt";
            Response.AppendHeader("Content-Disposition", "attachment; filename=MyOwnTextFile.txt");
            Response.Flush();
            Response.Close();

        }
        catch (Exception ex)
        {
            ErrorMessage.Text = "The file could not be created, the errormessage is: " + ex.ToString();
        }
        finally
        {
        }
    }
    protected void btnDownload_Click(object sender, EventArgs e)
    {
        // This code will will give the user a "Save As Dialog" to download a text file from our
        // webserver when he has clicked the button. If the file doesnt exist we want to get 
        // a FileNotFound exception and therefore we have code in the "Else" statement. The
        // term "octet-stream" makes it possible to download any type of file.

        // The Try/Catch/Finally block is used to handle exceptions.
        try
        {
            
            string FilePath = "files/mytestfile.txt";
            
            FileInfo LookForFile = new FileInfo(Server.MapPath(FilePath));

            if (LookForFile.Exists)
            {
                // Give the user a Save As Dialog to download the text file
                Response.Clear();
                Response.ContentType = ("application/octet-stream");
                Response.AppendHeader("Content-Disposition", "attachment; filename=MyOwnFile.txt");
                Response.WriteFile(Server.MapPath(FilePath));
                Response.Flush();
                Response.Close();
            }
            else
            {
                throw new FileNotFoundException();
            }
        }
        catch (FileNotFoundException ex)
        {
            ErrorMessage2.Text = "The file could not be downloaded, the errormessage is: " + ex.ToString();
        }
        finally
        {
        }
    }
}
